@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0903';
+our $VERSION = '0.0904';
 
 use Moo;
 use MIDI::Simple;
@@ -104,22 +104,22 @@ sub metronome {
     for my $n ( 1 .. $self->beats * $bars ) {
         if ( $n % 2 == 0 )
         {
-            $self->note( $self->quarter, $self->open_hh, $self->snare );
+            $self->note( $self->quarter, $self->closed_hh, $self->snare );
         }
         else {
             if ( $flag == 0 )
             {
-                $self->note( $self->quarter, $self->open_hh, $self->kick );
+                $self->note( $self->quarter, $self->closed_hh, $self->kick );
             }
             else
             {
                 if ( $i % 2 == 0 )
                 {
-                    $self->note( $self->quarter, $self->open_hh, $self->kick );
+                    $self->note( $self->quarter, $self->closed_hh, $self->kick );
                 }
                 else
                 {
-                    $self->note( $self->eighth, $self->open_hh, $self->kick );
+                    $self->note( $self->eighth, $self->closed_hh, $self->kick );
                     $self->note( $self->eighth, $self->kick );
                 }
             }
@@ -196,7 +196,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0903
+version 0.0904
 
 =head1 SYNOPSIS
 
